@@ -34,6 +34,8 @@ exponentiate <- function(data, col = "estimate") {
 #' @return A `tibble` potentially with a `.rownames` column
 #' @noRd
 #'
+
+
 as_augment_tibble <- function(data) {
   if (inherits(data, "matrix") & is.null(colnames(data))) {
     stop(
@@ -61,6 +63,16 @@ as_augment_tibble <- function(data) {
   df
 }
 
+# adapted from ps:::is_cran_check()
+is_cran_check <- function() {
+  if (identical(Sys.getenv("NOT_CRAN"), "true")) {
+    FALSE
+  }
+  else {
+    Sys.getenv("_R_CHECK_PACKAGE_NAME_", "") != ""
+  }
+}
+
 #' Convert a data.frame or matrix to a tibble
 #'
 #' This function is meant for use inside `tidy.*` methods.
@@ -197,7 +209,8 @@ unrowname <- function(x) {
 #' @param type.residuals Type of residuals to compute; by default
 #' same as `type`
 #' @param se.fit Value to pass to predict's `se.fit`, or NULL for
-#' no value
+#' no value. Ignored for model types that do not accept an `se.fit`
+#' argument
 #' @param ... extra arguments (not used)
 #'
 #' @export
@@ -219,9 +232,11 @@ augment_columns <- function(x, data, newdata = NULL, type, type.predict = type,
     args$newdata <- newdata
   }
   if (!missing(type.predict)) {
-    args$type <- type.predict
+    args$type <- type.predict[1]
+  }
+  if (!inherits(x, "betareg")) {
+    args$se.fit <- se.fit
   }
-  args$se.fit <- se.fit
   args <- c(args, list(...))
 
 
@@ -473,7 +488,7 @@ augment_newdata <- function(x, data, newdata, .se_fit, interval = NULL, ...) {
 # this version adds a terms column
 broom_confint <- function(x, ...) {
   # warn on arguments silently being ignored
-  ellipsis::check_dots_used()
+  rlang::check_dots_used()
   ci <- suppressMessages(confint(x, ...))
 
   # confint called on models with a single predictor
@@ -491,7 +506,7 @@ broom_confint <- function(x, ...) {
 # this version adds a terms column
 broom_confint_terms <- function(x, ...) {
   # warn on arguments silently being ignored
-  ellipsis::check_dots_used()
+  rlang::check_dots_used()
   ci <- suppressMessages(confint(x, ...))
 
   # confint called on models with a single predictor
